<?php
/**
 * Project:
 * Contenido Content Management System
 *
 * Description:
 * Functions for UTF8 decoding
 *
 * Requirements:
 * @con_php_req 4.x
 *
 *
 * @package    Contenido Frontend classes
 * @version    1.0.0
 * @author     Tiago Gomes
 * @copyright  Tiago Gomes <www.tiago.de>
 * @license
 * @link       http://www.tiago.de
 * @link       http://forum.contenido.org/viewtopic.php?p=134520#p134520
 * @since      file available since contenido release 4.8.14
 * @deprecated
 * @brief
 * @file       functions.include.UTF8decoding.php
 * @date       2010-12-22
 *
 * {@internal
 *   created 2010
 *   modified xxxx-xx-xx, [Modifier Name], [Description]
 *   ...
 *
 * }}
 *
 */

if(!defined('CON_FRAMEWORK')) {
	die('Illegal call');
}

/**
 * Needed functions for UTF8 and PHP4
 * Posted by "laurynas.butkus@gmail.com" (15-May-2007) at http://us2.php.net/manual/de/function.html-entity-decode.php
 * Changed by "akniep@rayo.info" (13-July-2007) at http://us2.php.net/manual/de/function.html-entity-decode.php
 * Changed by "Fabian" (28-September-2007) at http://us2.php.net/manual/de/function.html-entity-decode.php
 * --------
 * In PHP4 html_entity_decode() is not working well with UTF-8 spitting: "Warning: cannot yet handle MBCS in html_entity_decode()!".
 * This is working solution combining several workarounds:
 */
function html_entity_decode_utf8($string) {
    static $trans_tbl;

    // replace numeric entities
    $string = preg_replace('~&#x0*([0-9a-f]+);~ei', 'code2utf(hexdec("\\1"))', $string);
    $string = preg_replace('~&#0*([0-9]+);~e', 'code2utf(\\1)', $string);

    // replace literal entities
    if (!isset($trans_tbl)) {
        $trans_tbl = array();

        foreach (get_html_translation_table(HTML_ENTITIES) as $val=>$key)
            $trans_tbl[$key] = utf8_encode($val);
    }

    return strtr($string, $trans_tbl);
}

function code2utf($num) {
    if ($num < 0)
        return FALSE;

    if ($num < 128) return chr($num);

    // Removing / Replacing Windows Illegals Characters
    if ($num < 160) {
            if ($num==128) $num=8364;
        elseif ($num==129) $num=160; // (Rayo:) #129 using no relevant sign, thus, mapped to the saved-space #160
        elseif ($num==130) $num=8218;
        elseif ($num==131) $num=402;
        elseif ($num==132) $num=8222;
        elseif ($num==133) $num=8230;
        elseif ($num==134) $num=8224;
        elseif ($num==135) $num=8225;
        elseif ($num==136) $num=710;
        elseif ($num==137) $num=8240;
        elseif ($num==138) $num=352;
        elseif ($num==139) $num=8249;
        elseif ($num==140) $num=338;
        elseif ($num==141) $num=160; // (Rayo:) #129 using no relevant sign, thus, mapped to the saved-space #160
        elseif ($num==142) $num=381;
        elseif ($num==143) $num=160; // (Rayo:) #129 using no relevant sign, thus, mapped to the saved-space #160
        elseif ($num==144) $num=160; // (Rayo:) #129 using no relevant sign, thus, mapped to the saved-space #160
        elseif ($num==145) $num=8216;
        elseif ($num==146) $num=8217;
        elseif ($num==147) $num=8220;
        elseif ($num==148) $num=8221;
        elseif ($num==149) $num=8226;
        elseif ($num==150) $num=8211;
        elseif ($num==151) $num=8212;
        elseif ($num==152) $num=732;
        elseif ($num==153) $num=8482;
        elseif ($num==154) $num=353;
        elseif ($num==155) $num=8250;
        elseif ($num==156) $num=339;
        elseif ($num==157) $num=160; // (Rayo:) #129 using no relevant sign, thus, mapped to the saved-space #160
        elseif ($num==158) $num=382;
        elseif ($num==159) $num=376;
    } //if

    if ($num < 2048) return chr(($num >> 6) + 192).chr(($num & 63) + 128);
    if ($num < 65536) return chr(($num >> 12) + 224).chr((($num >> 6) & 63) + 128).chr(($num & 63) + 128);
    if ($num < 2097152) return chr(($num >> 18) + 240).chr((($num >> 12) & 63) + 128).chr((($num >> 6) & 63) + 128).chr(($num & 63) + 128);
    return '';
}

?>
